@@ -33,7 +33,10 @@ def with_log(fn=None, *, logger=None, is_debug=False):
             logger.debug(
                 f'func({f.__name__}) running(args={args}, kwargs={kwargs})')
             result = r(f, is_debug=is_debug)(*args, **kwargs)
-            logger.debug(f'func({f.__name__}) result: {result}')
+            if isinstance(result, Exception):
+                logger.error(f'func({f.__name__}) error: {result}')
+            else:
+                logger.debug(f'func({f.__name__}) result: {result}')
             return result
 
         return _inner
