@@ -2,8 +2,9 @@ import functools
 import logging
 
 
-def params_check(fn=None, *, required: list = None, optional: list = None):
+def params_check(fn=None, *, required: list = None, optional: list = None, debug=False):
     logger = logging.getLogger('__params_check__')
+    debug and logger.setLevel(logging.DEBUG)
 
     def _check_required(func_name: str, **kwargs):
         for item in (required or []):
@@ -26,3 +27,6 @@ def params_check(fn=None, *, required: list = None, optional: list = None):
         return _inner
 
     return callable(fn) and inner(fn) or inner
+
+
+__all__ = ('params_check',)
